plot.GPCMlasso: Plot function for GPCMlasso

View source: R/plot.GPCMlasso.R

plot.GPCMlassoR Documentation

Plot function for GPCMlasso

Description

Plot function for a GPCMlasso object. Plots coefficient paths along the tuning parameter lambda.

Usage

## S3 method for class 'GPCMlasso'
plot(x, select = c("BIC", "AIC", "cAIC", "cv"),
type = c("DIF", "Variable"), variable.scale = c("effect", "internal"),
log.lambda = TRUE, panels_per_page = 1, panels = "all",
columns = NULL, ask_new = TRUE, lambda.lines = TRUE,
equal_range = TRUE, add.to.lambda = 0, items_per_page = NULL,
items = NULL, plots = NULL, ...)

Arguments

x

GPCMlasso object.

select

Specifies which criterion to use for the optimal model.

type

Which plot type should be used. "DIF" means that one plot panel per item is shown. "Variable" means that one plot panel per variable is shown.

variable.scale

Only relevant for type = "Variable". "effect" plots interpretable response-effect paths. "internal" plots the internal GPCMlasso parameter paths.

log.lambda

A logical value indicating whether lambda or log(lambda) should be used.

panels_per_page

Number of plot panels per page.

panels

Panels to be shown. If "all", all panels are shown. For type = "DIF", panels refers to item panels. For type = "Variable", panels refers to covariate panels. Panels can be specified by numeric indices or names.

columns

Number of columns when several plot panels are shown on one page.

ask_new

If TRUE, the user is asked before plotting the next page.

lambda.lines

Whether vertical lines should be drawn for all lambda values.

equal_range

Whether equal y-axis ranges should be used.

add.to.lambda

Constant added to lambda before log transformation.

items_per_page

Deprecated. Use panels_per_page instead.

items

Deprecated. Use panels instead.

plots

Deprecated. Use panels instead.

...

Further plot arguments.

Details

For type = "DIF", one plot panel per item is created and the internal item-specific parameters are shown. The argument panels can be used to restrict the output to selected item panels.

For type = "Variable", one plot panel per covariate is created. The argument panels can be used to restrict the output to selected covariate panels. By default, the paths are shown on the response-effect scale, i.e. global effect minus item-specific DIF parameter. This corresponds to the interpretable effect of a covariate on the local logit under the internal DIF parameterization.

For type = "Variable", effect-scale plots are recommended for interpretation.


GPCMlasso documentation built on Sept. 8, 2026, 5:08 p.m.