View source: R/ctrl_GPCMlasso.R
| ctrl_GPCMlasso | R Documentation |
Control parameters for penalty terms and for tuning the fitting algorithm.
ctrl_GPCMlasso(
log.lambda = TRUE,
lambda = NULL,
l.lambda = 50,
lambda.min = 0.1,
penalize.main.effects = FALSE,
fuse.per.variable = FALSE,
scale.covariate.effects = TRUE,
include.item.effects = TRUE,
adaptive = TRUE,
weight.penalties = TRUE,
ada.lambda = 1e-04,
ada.power = 1,
Q = 15,
lambda2 = 1e-04,
cvalue = 1e-05,
trace = TRUE,
folds = 10,
cores = 25,
null_thresh = 0.01,
gradtol = 1e-06,
steptol = 1e-06,
iterlim = 500,
precision = 3,
all.dummies = FALSE,
ctrl.gpcm = list()
)
log.lambda |
Logical. Should the grid of tuning parameters be created on a log scale? |
lambda |
Optional vector of tuning parameters. If |
l.lambda |
Length of the tuning parameter grid. |
lambda.min |
Minimal value used for the automatically created tuning parameter grid. |
penalize.main.effects |
Logical. Should global covariate effects be penalized? |
fuse.per.variable |
Logical. Should item-specific effects referring to the same covariate be fused across items? |
scale.covariate.effects |
Logical. If |
include.item.effects |
Logical. If |
adaptive |
Logical. Should adaptive lasso weights be used? |
weight.penalties |
Logical. Should penalties be weighted according to the number of penalty terms and corresponding parameters? |
ada.lambda |
Tuning parameter for ridge-regularized estimation of adaptive weights. |
ada.power |
Power used for adaptive weights. |
Q |
Number of nodes used in Gauss-Hermite quadrature. |
lambda2 |
Ridge penalty on all coefficients except slope parameters. |
cvalue |
Internal parameter for the quadratic approximation of the
|
trace |
Logical. Should progress information be printed? |
folds |
Number of folds for cross-validation. |
cores |
Number of cores used for parallel computation. |
null_thresh |
Threshold used to distinguish zero from non-zero values. |
gradtol |
Parameter for optimization accuracy. See |
steptol |
Parameter for optimization accuracy. See |
iterlim |
Parameter for optimization accuracy. See |
precision |
Number of decimal places used to round coefficient estimates in selected output methods. |
all.dummies |
Logical. Should all dummy variables be included for factors with more than two categories? |
ctrl.gpcm |
List of control arguments for the initial
|
A list of control parameters used by GPCMlasso.
Gunther Schauberger
gunther.schauberger@tum.de
Schauberger, G. and Mair, P. (2020). A regularization approach for the detection of differential item functioning in generalized partial credit models. Behavior Research Methods, 52, 279–294. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3758/s13428-019-01224-2")}
GPCMlasso,
plot.GPCMlasso
ctrl <- ctrl_GPCMlasso()
str(ctrl)
ctrl_small <- ctrl_GPCMlasso(
l.lambda = 5,
cores = 1,
trace = FALSE
)
ctrl_fusion <- ctrl_GPCMlasso(
l.lambda = 5,
cores = 1,
penalize.main.effects = TRUE,
include.item.effects = TRUE,
fuse.per.variable = TRUE,
scale.covariate.effects = FALSE,
trace = FALSE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.