| tenseness_small | R Documentation |
A small subset of the Freiburg Complaint Checklist data. The data contain 5 items, out of the 8 items in the full data set, corresponding to the scale Tenseness, together with two covariates.
A data frame containing a subset of the Freiburg Complaint
Checklist data with 200 observations. The complete data set is available as
tenseness. The item responses refer to the scale
Tenseness and are measured on a 5-point Likert scale, where low
values correspond to low frequencies or low intensities of the respective
complaint and high values correspond to high frequencies or high intensities.
The data frame contains the following variables:
Do you have clammy hands?
Do you have sudden attacks of sweating?
Do you notice that you behave clumsily?
Do your hands shake frequently, for example when lighting a cigarette or when holding a cup?
Do you notice that your hands are restless?
Gender of the person.
Age of the person.
ZPID (2013). PsychData of the Leibniz Institute for Psychology Information ZPID. Trier: Center for Research Data in Psychology.
Fahrenberg, J. (2010). Freiburg Complaint Checklist [Freiburger Beschwerdenliste (FBL)]. Goettingen: Hogrefe.
GPCMlasso,
ctrl_GPCMlasso,
plot.GPCMlasso,
trait.posterior
data(tenseness_small)
## Formula with five ordinal items and two covariates
form_cov <- as.formula(
paste(
"cbind(",
paste(colnames(tenseness_small)[1:5], collapse = ","),
") ~ Gender + Age"
)
)
## Not run:
## ------------------------------------------------------------
## Classical DIF analysis
## ------------------------------------------------------------
fit_dif <- GPCMlasso(
formula = form_cov,
data = tenseness_small,
model = "GPCM",
control = ctrl_GPCMlasso(
cores = 1,
l.lambda = 10,
trace = FALSE
)
)
summary(fit_dif)
plot(
fit_dif,
type = "DIF",
panels_per_page = 2,
columns = 2,
ask_new = FALSE
)
## ------------------------------------------------------------
## Explanatory GPCM-X with global and item-specific effects
## and fusion penalty
## ------------------------------------------------------------
set.seed(1860)
fit_fusion <- GPCMlasso(
formula = form_cov,
data = tenseness_small,
model = "GPCM",
main.effects = TRUE,
cv = TRUE,
control = ctrl_GPCMlasso(
cores = 1,
l.lambda = 10,
folds = 2,
penalize.main.effects = TRUE,
include.item.effects = TRUE,
fuse.per.variable = TRUE,
scale.covariate.effects = FALSE,
trace = FALSE
)
)
summary(
fit_fusion,
effect.scale = "effect"
)
## Available covariate panels
fit_fusion$design_list$x.names
plot(
fit_fusion,
type = "Variable",
panels = fit_fusion$design_list$x.names,
panels_per_page = 2,
columns = 2,
variable.scale = "effect",
select = "cv",
ask_new = FALSE
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.